:py:mod:`pymerlin`
==================

.. py:module:: pymerlin

.. autodoc2-docstring:: pymerlin
   :parser: myst
   :allowtitles:

Submodules
----------

.. toctree::
   :titlesonly:
   :maxdepth: 1

   pymerlin.duration
   pymerlin.model_actions
